==> upload-api-client-internal-2.43.0.tgz: package/src/models/UploadWidgetConfig.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { MimeType } from "./MimeType";
import type { UploadWidgetContainer } from "./UploadWidgetContainer";
import type { UploadWidgetEditor } from "./UploadWidgetEditor";
import type { UploadWidgetLayout } from "./UploadWidgetLayout";
import type { UploadWidgetLocale } from "./UploadWidgetLocale";
import type { UploadWidgetOnUpdate } from "./UploadWidgetOnUpdate";
import type { UploadWidgetStyles } from "./UploadWidgetStyles";

/**
 * The configuration object passed to the upload widget's `open()` method has this structure:
 */
export type UploadWidgetConfig = {
  container?: UploadWidgetContainer;
  editor?: UploadWidgetEditor;
  layout?: UploadWidgetLayout;
  locale?: UploadWidgetLocale;
  /**
   * Maximum number of files allowed.
   *
   * Default: infinity if multi=true
   */
  maxFileCount?: number;
  /**
   * Maximum file size allowed.
   *
   * Default: infinity
   */
  maxFileSizeBytes?: number;
  /**
   * An arbitrary JSON object to store against the uploaded file(s) as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * File type filter.
   */
  mimeTypes?: Array<MimeType>;
  /**
   * Enables/disables multiple file uploads.
   *
   * Default: false
   */
  multi?: boolean;
  onUpdate?: UploadWidgetOnUpdate;
  /**
   * The path to upload the file(s) to.
   */
  path?: FilePathDefinition;
  /**
   * Shows/hides the 'finish' button, which is displayed after files are uploaded.
   *
   * If `showFinishButton = false`, `multi = false`, and `layout = "modal"`, then the modal will close immediately after the file is uploaded (instead of showing the file to the user).
   *
   * Default: true
   */
  showFinishButton?: boolean;
  /**
   * Shows/hides the 'remove' button, which is displayed next to each file after it's uploaded.
   *
   * Default: true
   */
  showRemoveButton?: boolean;
  styles?: UploadWidgetStyles;
  /**
   * The tags you specify here determine which rules will be executed for the upload(s).
   *
   * You create rules in the Upload Dashboard, and choose which tags trigger each rule.
   *
   * Rules include: max file size checks, traffic limit checks, rate limit checks, etc.
   */
  tags?: Array<FileTagName>;
};

==> upload-api-client-internal-2.55.0.tgz: package/src/models/UploadWidgetConfig.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { MimeType } from "./MimeType";
import type { SingleParameterFunction } from "./SingleParameterFunction";
import type { UploadWidgetContainer } from "./UploadWidgetContainer";
import type { UploadWidgetEditor } from "./UploadWidgetEditor";
import type { UploadWidgetLayout } from "./UploadWidgetLayout";
import type { UploadWidgetLocale } from "./UploadWidgetLocale";
import type { UploadWidgetStyles } from "./UploadWidgetStyles";

/**
 * The configuration object passed to the Upload Widget's `open()` method has this structure:
 */
export type UploadWidgetConfig = {
  container?: UploadWidgetContainer;
  editor?: UploadWidgetEditor;
  layout?: UploadWidgetLayout;
  locale?: UploadWidgetLocale;
  /**
   * Maximum number of files allowed.
   *
   * Default: infinity if multi=true
   */
  maxFileCount?: number;
  /**
   * Maximum file size allowed.
   *
   * Default: infinity
   */
  maxFileSizeBytes?: number;
  /**
   * An arbitrary JSON object to store against the uploaded file(s) as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * File type filter.
   */
  mimeTypes?: Array<MimeType>;
  /**
   * Enables/disables multiple file uploads.
   *
   * Default: false
   */
  multi?: boolean;
  /**
   * Callback taking a single parameter: an array of UploadWidgetResult.
   *
   * Fired each time a file is uploaded or removed.
   */
  onUpdate?: SingleParameterFunction;
  /**
   * Callback taking a single parameter: a DOM File object.
   *
   * Fired before each file upload.
   *
   * If ```Promise<string>``` is returned, then the string is displayed to the user as a validation error message and the upload is cancelled.
   *
   * If ```Promise<undefined>``` is returned, then the upload is allowed to continue.
   */
  onValidate?: SingleParameterFunction;
  /**
   * The path to upload the file(s) to.
   */
  path?: FilePathDefinition;
  /**
   * Shows/hides the 'finish' button, which is displayed after files are uploaded.
   *
   * If `showFinishButton = false`, `multi = false`, and `layout = "modal"`, then the modal will close immediately after the file is uploaded (instead of showing the file to the user).
   *
   * Default: true
   */
  showFinishButton?: boolean;
  /**
   * Shows/hides the 'remove' button, which is displayed next to each file after it's uploaded.
   *
   * Default: true
   */
  showRemoveButton?: boolean;
  styles?: UploadWidgetStyles;
  /**
   * The tags you specify here determine which rules will be executed for the upload(s).
   *
   * You create rules in the Upload Dashboard, and choose which tags trigger each rule.
   *
   * Rules include: max file size checks, traffic limit checks, rate limit checks, etc.
   */
  tags?: Array<FileTagName>;
};
